#
# spec file for package python-curtsies
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-curtsies
Version:        0.3.1
Release:        lp152.2.1
Summary:        Curses-like terminal wrapper, with colored strings!
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/bpython/curtsies
Source:         https://files.pythonhosted.org/packages/source/c/curtsies/curtsies-%{version}.tar.gz
# https://github.com/bpython/curtsies/pull/127
Patch0:         remove-nose.patch
BuildRequires:  %{python_module blessings}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pyte}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wcwidth}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-blessings
Requires:       python-wcwidth
BuildArch:      noarch
%if %{with python2}
BuildRequires:  python2-typing
%endif
%if %{python_version_nodots} < 35
BuildRequires:  python3-typing
%endif
%ifpython2
Requires:       python-typing
%endif
%ifpython3
%if %{python3_version_nodots} < 35
Requires:       python-typing
%endif
%endif
%python_subpackages

%description
Curses-like terminal wrapper with a display based on compositing 2d
arrays of text.

%prep
%setup -q -n curtsies-%{version}
%patch0 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec -m unittest discover -s tests -v

%files %{python_files}
%license LICENSE
%doc readme.md
%{python_sitelib}/*

%changelog
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Apr  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Add remove-nose.patch
* Thu Apr  2 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 0.3.1
  * Add "dark" format function
  * Add Input option to disable terminal start/stop. Thanks George Kettleborough!
  * Fix Py3.6 compatibility. Thanks Po-Chuan Hsieh!
  * Assorted fixes, thanks Jakub Wilk and Manuel Mendez!
- Drop upstreamed python-curtsies-dont-require-typing-for-python3.5.patch
* Mon Mar 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Enable verbosity of tests to see what is validated
* Wed Jul 18 2018 tchvatal@suse.com
- Add dependency over wcwidth which is imported by the package
* Thu Apr 26 2018 badshah400@opensuse.org
- Add python-curtsies-dont-require-typing-for-python3.5.patch: The
  typing module is only required for python3.4 and lower; patch
  taken from upstream git (gh#bpython/curtsies#111).
* Tue Feb 20 2018 arun@gmx.de
- specfile:
  * update copyright year
  * update url
  * require typing module for older python versions
- update to version 0.3.0:
  * Change name of "dark" color to "black"
  * Drop support for Python 2.6 and 3.3
  * New FmtStr method width_aware_splitlines which cuts up a FmtStr in
    linear time
- changes from version 0.2.12:
  * fix accidentally quadratic width_aware_slice behavior (fixes
    bpython #729) This bug causes bpython to hang on large
    output. Thanks Ben Wiederhake!
  * Allow curtsies to be run on non-main threads (useful for bpython
    [#555]) This should allow bpython to be run in a variety of
    situations like Django's runserver
  * Add function keys for some keyboard/terminal setups
* Thu Aug 31 2017 toddrme2178@gmail.com
- Update to version 0.2.11
  * Add sequences for home and end (fixes Curtsies #78)
  * fix #90 again
  * strip ansi escape sequences if parsing fmtstr input fails
  * prevent invalid negative cursor positions in CursorAwareWindow (fixes bpython #607)
  * '\x1bOA' changed from ctrl-arrow key to arrow key (fixes bpython #621)
  * alternate codes for F1-F4 (fixes bpython #626)
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Mon Aug 15 2016 badshah400@gmail.com
- Initial package.
